# Installation

Run `composer require dedi/sylius-dpd-pick-up-plugin`

Change your `config/bundles.php` file to add the line for the plugin :

```php
<?php

return [
    //..
    Dedi\SyliusDpdPickUpPlugin\DediSyliusDpdPickUpPlugin::class => ['all' => true],
];
```

Create `dedi_sylius_dpd_pick_up_plugin.yaml` file into `config/packages` folder to import required config

```yaml
# config/packages/dedi_sylius_dpd_pick_up_plugin.yaml

imports:
  - { resource: "@DediSyliusDpdPickUpPlugin/Resources/config/config.yml" }
  
dedi_sylius_dpd_pick_up_plugin:
  mypudo_url: 'http://mypudo.pickup-services.com/mypudo/mypudo.asmx' # default value
  carrier: 'EXA' # test values
  key: 'deecd7bc81b71fcc0e292b53e826c48f' # test values

```

## Update your entities

```php
use Dedi\SyliusDpdPickUpPlugin\Entity\OrderInterface;
use Dedi\SyliusDpdPickUpPlugin\Entity\OrderTrait as DediDpdPickUpOrderTrait;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\Order as BaseOrder;

/**
 * @ORM\Entity
 * @ORM\Table(name="sylius_order")
 */

class Order extends BaseOrder implements OrderInterface
{
    use DediDpdPickUpOrderTrait;
}
```

```php
use Dedi\SyliusDpdPickUpPlugin\Entity\ShippingMethodInterface;
use Dedi\SyliusDpdPickUpPlugin\Entity\ShippingMethodTrait as DediDpdPickUpShippingMethodTrait;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\ShippingMethod as BaseShippingMethod;

/**
 * @ORM\Entity
 * @ORM\Table(name="sylius_shipping_method")
 */
class ShippingMethod extends BaseShippingMethod implements ShippingMethodInterface
{
    use DediDpdPickUpShippingMethodTrait;
}
```

Don't forget to update your `_sylius.yaml` file

```yaml
sylius_order:
    resources:
        order:
            classes:
                model: Application\Entity\Order

sylius_shipping:
    resources:
        shipping_method:
            classes:
                model: Application\Entity\ShippingMethod

```

## Customize the provided templates

```shell
cp -R vendor/dedi/sylius-dpd-pick-up-plugin/tests/Application/templates/* templates
```

## Create and execute database migrations:

```shell
bin/console doctrine:migrations:diff
bin/console doctrine:migrations:migrate
```
